@@ -3,14 +3,14 @@
  */
 
 #ifdef __hpux
-    #define DEFAULT_MAIL_COMMAND "/usr/bin/mailx -s"
+    #define DEFAULT_MAIL_COMMAND "/usr/bin/mailx"
     #define COMPRESS_COMMAND "/usr/contrib/bin/gzip"
     #define UNCOMPRESS_COMMAND " /usr/contrib/bin/gunzip"
     #define STATEFILE "/var/run/logrotate.status"
 #endif
 
 #ifdef SunOS
-    #define DEFAULT_MAIL_COMMAND "/usr/bin/mailx -s"
+    #define DEFAULT_MAIL_COMMAND "/usr/bin/mailx"
     #define COMPRESS_COMMAND "/usr/local/bin/gzip"
     #define UNCOMPRESS_COMMAND "/usr/local/bin/gunzip"
     #define STATEFILE "/var/log/logrotate.status"
@@ -20,7 +20,7 @@
  * Default settings for Linux - leave these last.
  */
 #ifndef DEFAULT_MAIL_COMMAND
-    #define DEFAULT_MAIL_COMMAND "/bin/mail -s"
+    #define DEFAULT_MAIL_COMMAND "/bin/mail"
 #endif
 
 #ifndef COMPRESS_COMMAND
